@@ -14,7 +14,7 @@ BEGIN {
     }
 }
 
-our $VERSION = '0.5';
+our $VERSION = '0.51';
 
 our @ISA = qw(Lemonldap::NG::Handler::SharedConf);
 
@@ -28,11 +28,11 @@ my ( $dbh, $cfgNum ) = ( undef, 0 );
 sub localInit($$) {
     my ( $class, $args ) = @_;
     $args->configStorage = {
-	type        => 'DBI',
-	dbiChain    => $args->{dbiChain},
-	dbiUser     => $args->{dbiUser},
-	dbiPassword => $args->{dbiPassword},
-	dbiTable    => $args->{dbiTable},
+        type        => 'DBI',
+        dbiChain    => $args->{dbiChain},
+        dbiUser     => $args->{dbiUser},
+        dbiPassword => $args->{dbiPassword},
+        dbiTable    => $args->{dbiTable},
     };
     $class->SUPER::localInit($args);
 }
@@ -92,10 +92,10 @@ Call your package in /apache-dir/conf/httpd.conf :
 
   PerlRequire MyFile
   # TOTAL PROTECTION
-  PerlInitHandler My::Package
+  PerlHeaderParserHandler My::Package
   # OR SELECTED AREA
   <Location /protected-area>
-    PerlInitHandler My::Package
+    PerlHeaderParserHandler My::Package
   </Location>
 
 The configuration is loaded only at Apache start. Create an URI to force
@@ -106,7 +106,7 @@ configuration reload, so you don't need to restart Apache at each change :
     Order deny,allow
     Deny from all
     Allow from my.manager.com
-    PerlInitHandler My::Package->refresh
+    PerlHeaderParserHandler My::Package->refresh
   </Location>
 
 =head1 DESCRIPTION
